﻿using System.Diagnostics;
using Models;
using Stub;
using DataContractPersistance;
using GameAtlas.Views;
using Microsoft.Extensions.Options;
using Microsoft.VisualBasic.FileIO;
using Models.API;

namespace GameAtlas;

/// <summary>
/// Classe partielle pour l'application principale.
/// </summary>
public partial class App : Application
{
    /// <summary>
    /// Nom du fichier de données.
    /// </summary>
    public string FileName { get; set; } = "data.json"; // data.xml

    /// <summary>
    /// Chemin du fichier de données.
    /// </summary>
    public string FilePath { get; set; } = Path.Combine(AppDomain.CurrentDomain.BaseDirectory);

    /// <summary>
    /// Gestionnaire principal de l'application.
    /// </summary>
    public Manager MyManager { get; private set; }

    private readonly IGDBClient _igdbClient;
    private readonly IGDBSettings _igdbSettings;

    /// <summary>
    /// Constructeur de l'application.
    /// </summary>
    public App(IGDBClient igdbClient, IOptions<IGDBSettings> igdbSettings)
	{
        MyManager = new Manager(new Stub.Stub(), _igdbClient);

        InitializeComponent();


        MyManager.ChargerDonnees();

        MainPage = new AppShell();

        _igdbClient = igdbClient;
        _igdbSettings = igdbSettings.Value;

        // For debug purposes, load games when the app starts
        LoadGames();
    }

    private async void LoadGames()
    {
        try
        {
            var games = await _igdbClient.GetGamesAsync();
            Debug.WriteLine($"Games: {games}");
        }
        catch (HttpRequestException ex)
        {
            Debug.WriteLine($"Request failed: {ex.Message}");
        }
    }
}
