﻿using System.Diagnostics;
using CommunityToolkit.Maui;
using GameAtlas.Views;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Configuration;
using Models;
using System.Reflection;
using Microsoft.Extensions.DependencyInjection;
using Models.API;

namespace GameAtlas;

/// <summary>
/// Classe principale du programme pour l'application Maui.
/// </summary>
public static class MauiProgram
{
    /// <summary>
    /// Crée et configure l'application MAUI.
    /// </summary>
    /// <returns>L'application MAUI configurée.</returns>
    public static MauiApp CreateMauiApp()
	{
		var builder = MauiApp.CreateBuilder();
        builder.Configuration.AddJsonFile(Path.Combine(FileSystem.AppDataDirectory, "appsettings.json"), optional: false, reloadOnChange: true);
        builder
			.UseMauiApp<App>()
            .UseMauiCommunityToolkit()
            .ConfigureFonts(fonts =>
			{
				// Open Sans
				fonts.AddFont("OpenSans-Regular.ttf", "OpenSansRegular");
				fonts.AddFont("OpenSans-Semibold.ttf", "OpenSansSemibold");

                fonts.AddFont("Aladin-Regular.ttf", "AladinRegular");

                fonts.AddFont("PTSansCaption-Regular.ttf", "PTSansCRegular");
                fonts.AddFont("PTSansCaption-Bold.ttf", "PTSansCBold");

                fonts.AddFont("PTSansNarrow-Regular.ttf", "PTSansNRegular");
                fonts.AddFont("PTSansNarrow-Bold.ttf", "PTSansNBold");

                fonts.AddFont("Roboto-Regular.ttf", "RobotoRegular");
				fonts.AddFont("Roboto-Bold.ttf", "RobotoBold");
				fonts.AddFont("Roboto-Black.ttf", "RobotoBlack");
            });

        // Register the HttpClient, AuthService, IGDBClient as a service
        builder.Services.AddSingleton<HttpClient>();
        builder.Services.AddSingleton<AuthService>();
        builder.Services.AddSingleton<IGDBClient>();

        // Bind the configuration section to IGDBSettings (for IGDB API access)
        var igdbSettings = new IGDBSettings();
        builder.Configuration.GetSection("IGDB").Bind(igdbSettings);
        builder.Services.AddSingleton(igdbSettings);

#if DEBUG
        builder.Logging.AddDebug();
#endif

		return builder.Build();
	}
}
